
The simulations directory contains the noisy time course that were asked to be
predicted in the Parameter Estimation challenge `DREAM6
<http://www.the-dream-project.org/result/estimation-model-parameters-challenge>`_.

The DREAM6 challenge had 2 sub-challenges with 3 models. The directory contains 6 files (3 times2).


Other files contained in this directory are copies or subset of the links to be
found at the bottom of the DREAM6 Parameter Estimation page (link above), which
may require permissions.

- dream6_ch2_gs.zip content is available in ./simulations
- scoring.zip is available in scoring
- dream6_parest_data_v4 has been copied and trimmed for large unneccerary files
  into ./models directory
- perturbations_without_noise.zip is kept as a zipped archive
